use strict;
use warnings;

# This test was generated for <lib/Test/File/ShareDir/Module.pm>
# using by Dist::Zilla::Plugin::Test::Compile::PerFile ( @Author::KENTNL/Test::Compile::PerFile ) version 0.003000
# with template 01-basic.t.tpl

use Test::More 0.89 tests => 1;

require_ok("lib/Test/File/ShareDir/Module.pm");

